@@ -18,14 +18,21 @@ class RruleToken(LexToken):
 
 
 class Rrule(Base):
-    def rrule(self, name: str, rrulepos: int, columns: List[str], values: List[Any], occurrences: slice):
+    def rrule(self, name: str, rrulepos: int, slicepos: int, columns: List[str], values: List[Any]):
         try:
             name = self.validator.validate_identifier(name)
+            if slicepos is not None:
+                del columns[slicepos]
             sqlColumns = self.validator.validate_rrule_columns(columns)
             sqlValues = []
             args = []
             for row in values:
                 ctx = Ctx(self.paramOffset, [])
+                occurrences = slice(100000)
+                if slicepos is not None:
+                    if row[slicepos] != 'NULL':
+                        occurrences = row[slicepos]
+                    del row[slicepos]
                 sqlVal = self.validator.validate_rrule_values(
                     rrulepos, row, ctx, occurrences)
                 if sqlVal:
